Immutable constructor
const
Immutable([
- String reason = ''
Creates annotation for being immutable with the given reason.
Implementation
const Immutable([this.reason = '']);
Creates annotation for being immutable with the given reason.
const Immutable([this.reason = '']);