Immutable class
Annotation on an immutable class.
Used to annotate a class declaration.
Indicates that the class, and all subtypes of it, must be immutable.
A class is immutable if all of the instance fields of the class, whether
defined directly or inherited, are final.
This class has a reason field that can be displayed as part of the error message if a subclass is not immutable.
See immutable for more details.
- Annotations
-
- @Target.new({TargetKind.classType, TargetKind.extensionType, TargetKind.mixinType})
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited