RecordUse class
Annotation on static method or class whose accesses will be recorded.
Applies to static functions, top-level functions, extension methods, or classes with constant constructors.
During compilation, all statically resolved calls to an annotated function or accesses to constant instances of an annotated class in reachable code are recorded. Information about these usages is then made available to post-compile steps.
Only usages in reachable code (executable code) are tracked. Usages appearing within metadata (annotations) are ignored.
- Annotations
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited