RecordUse constructor
const
RecordUse()
Creates a RecordUse instance.
This annotation can be placed as an annotation on functions or classes whose usages in reachable code should be registered.
Implementation
const RecordUse();